
History
=======

1.0a4 (2016-06-10)
------------------

- Fixes measurements of zope request, also add more detailed metrics.
  [jensens]


1.0a3 (2016-06-09)
------------------

- Measure time a zope request needs.
  [jensens]


1.0a2 (2016-03-22)
------------------

- Refactored: ZConfig best practice
  [jensens]

- Fix: Strip trailing dot from prefix
  [jensens]


1.0a1 (2016-03-22)
------------------

- Fix: README was wrong.
  [jensens]


1.0a0 (2016-03-22)
------------------

- made it work [jensens, 2016-03-17]

